# Contributing to bimmer_connected

Contributions to bimmer_connected are welcome!

The process is straight-forward.

 - Fork the bimmer_connected [git repository](https://github.com/bimmerconnected/bimmer_connected).
 - Write the code for your new feature, change or bugfix.
 - Please make sure that your code passes the checks in `.github/workflows/test.yml`. We currently test against `flake8`, `pylint` and our own `pytest` suite. And please add tests where it makes sense. The more the better.
 - Create a Pull Request against the [**master**](https://github.com/bimmerconnected/bimmer_connected/tree/master) branch of bimmer_connected.

## Feature suggestions

If you want to suggest a new feature for bimmer_connected, please open one [here](https://github.com/bimmerconnected/bimmer_connected/discussions/new).
